//
//  ViewController.m
//  FlexGridLongPress
//
//  Created by kelley.ricker on 5/25/16.
//  Copyright © 2016 GrapeCity. All rights reserved.
//

#import "ViewController.h"
#import "CustomerData.h"
#import <XuniFlexGridKit/XuniFlexGridKit.h>

@interface ViewController (){
    FlexGrid *flex;
}
@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.
    self.edgesForExtendedLayout = UIRectEdgeNone;
    self.title = @"FlexGrid Long Press";
    flex = [[FlexGrid alloc] init];
    flex.isReadOnly = true;
    
    NSString *countries = @"United States|Germany|United Kingdom|Japan|Italy|Greece";
    NSArray *countriesArray = [countries componentsSeparatedByString:@"|"];
    
    NSString *cities = @"New York|Berlin|London|Tokyo|Rome|Athens";
    NSArray *citiesArray = [cities componentsSeparatedByString:@"|"];
    
    NSString *address = @"11 Main St.|347 Broad Ave.|864 Grand Blvd.|31 Panoramic Way|787 Green St.|100 Golden Ave.|2 Park St.| 96 Grant Way";
    NSArray *addressArray = [address componentsSeparatedByString:@"|"];
    
    flex.selectionMode = FlexSelectionModeRow;
    flex.autoGenerateColumns = false;
    FlexColumn *identifier = [[FlexColumn alloc] init];
    identifier.binding    = @"customerID";
    identifier.header = @"ID";
    identifier.isReadOnly = true;
    identifier.widthType  = FlexColumnWidthPixel;
    identifier.width = 45;
    [flex.columns addObject:identifier];
    
    FlexColumn *firstName = [[FlexColumn alloc] init];
    firstName.binding   = @"firstName";
    firstName.widthType = FlexColumnWidthStar;
    firstName.width     = 1;
    [flex.columns addObject:firstName];
    
    FlexColumn *lastName = [[FlexColumn alloc] init];
    lastName.binding   = @"lastName";
    lastName.widthType = FlexColumnWidthStar;
    lastName.width     = 1;
    [flex.columns addObject:lastName];
    
    flex.detailProvider.detailHeight = 70;
    
    IXuniEventHandler rowHeaderLoadingEventHandler = ^(NSObject *sender, XuniEventArgs *args)
    {
        FlexGridRowHeaderLoadingEventArgs *e   = (FlexGridRowHeaderLoadingEventArgs *)args;
        UIButton                          *btn = [UIButton buttonWithType:UIButtonTypeCustom];
        [btn setImage:[UIImage imageNamed:@"show"] forState:(UIControlStateNormal)];
        [btn setImage:[UIImage imageNamed:@"hide"] forState:(UIControlStateSelected)];
        btn.imageView.contentMode = UIViewContentModeScaleAspectFit;
        e.button                  = btn;
    };
    
    [flex.detailProvider.gridRowHeaderLoading addHandler:rowHeaderLoadingEventHandler forObject:self];
    
    
    IXuniEventHandler detailCellCreatingHandler = ^(NSObject *sender, XuniEventArgs *args)
    {
        FlexGridDetailCellCreatingEventArgs* e = (FlexGridDetailCellCreatingEventArgs*)args;
        UIView *container = [[UIView alloc] init];
        container.backgroundColor = [UIColor whiteColor];
        UILabel *country = [[UILabel alloc]initWithFrame:CGRectMake(5, 5, 100, 20)];
        country.text = @"Country: ";
        UILabel *text = [[UILabel alloc]initWithFrame:CGRectMake(105, 5, 150, 20)];
        UILabel *city = [[UILabel alloc]initWithFrame:CGRectMake(5, 25, 100, 20)];
        city.text = @"City: ";
        UILabel *text2 = [[UILabel alloc]initWithFrame:CGRectMake(105, 25, 150, 20)];
        UILabel *address = [[UILabel alloc]initWithFrame:CGRectMake(5, 45, 100, 20)];
        address.text = @"Addess: ";
        UILabel *text3 = [[UILabel alloc]initWithFrame:CGRectMake(105, 45, 150, 20)];
        
        CustomerData *customer = (CustomerData*)e.row.dataItem;
        text.text = (NSString*)[countriesArray objectAtIndex:customer.countryID];
        text2.text = (NSString*)[citiesArray objectAtIndex:customer.countryID];
        text3.text = (NSString*)[addressArray objectAtIndex:customer.countryID];
        text.font = text2.font = text3.font =country.font = city.font = address.font = flex.font;
        
        [container addSubview:country];
        [container addSubview:text];
        [container addSubview:city];
        [container addSubview:text2];
        [container addSubview:address];
        [container addSubview:text3];
        e.view = container;
    };
    
    [flex.detailProvider.detailCellCreating addHandler:detailCellCreatingHandler forObject:self];
    
    UILongPressGestureRecognizer *longPress = [[UILongPressGestureRecognizer alloc] initWithTarget:self action:@selector(handleLongPress:)];
    longPress.numberOfTouchesRequired = 1;
    longPress.minimumPressDuration = 1.0f;
    longPress.allowableMovement = 10;
    longPress.delegate = self;
    [flex addGestureRecognizer:longPress];
    flex.itemsSource = [CustomerData getCustomerData:1000];
    flex.detailProvider.detailVisibilityMode = FlexGridDetailVisibilityModeExpandSingle;
    [self.view addSubview:flex];
}

-(void)handleLongPress:(UILongPressGestureRecognizer*)sender{
    CGPoint pressedPoint = [sender locationInView:flex];
    FlexHitTestInfo *hit = [[FlexHitTestInfo alloc] initWithGrid:flex atPoint:pressedPoint];
    if(sender.state == UIGestureRecognizerStateBegan){
        [flex.detailProvider showDetail:[flex.rows objectAtIndex:hit.row]];
    }
    if(sender.state == UIGestureRecognizerStateEnded){
        
        [flex.detailProvider hideDetail:[flex.rows objectAtIndex:hit.row]];
        //You can also extract the information in the cell as shown below
        //NSString *message = (NSString*)[flex getCellDataForRow:hit.row inColumn:hit.column formatted:true];
        //UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Alert" message:message delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil, nil];
        //[alert show];
    }
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}


- (void)viewDidLayoutSubviews{
    [super viewDidLayoutSubviews];
    
    flex.frame = CGRectMake(0, 0, self.view.bounds.size.width, self.view.bounds.size.height);

}
@end
